@@ -6,19 +6,22 @@
 # shellcheck source=configs/default_hooks/sxmo_hook_icons.sh
 . sxmo_hook_icons.sh
 # shellcheck source=scripts/core/sxmo_common.sh
-. "$(dirname "$0")/sxmo_common.sh"
+. sxmo_common.sh
+
+# We use this directory to store states, so it must exist
+mkdir -p "$XDG_RUNTIME_DIR/sxmo_calls"
 
 stderr() {
 	sxmo_log "$*"
 }
 
 cleanupnumber() {
-	if pn valid "$1"; then
+	if pnc valid "$1"; then
 		echo "$1"
 		return
 	fi
 
-	REFORMATTED="$(pn find ${DEFAULT_COUNTRY:+-c "$DEFAULT_COUNTRY"} "$1")"
+	REFORMATTED="$(pnc find ${DEFAULT_COUNTRY:+-c "$DEFAULT_COUNTRY"} "$1")"
 	if [ -n "$REFORMATTED" ]; then
 		echo "$REFORMATTED"
 		return
@@ -39,36 +42,36 @@ checkforfinishedcalls() {
 		FINISHEDNUMBER="$(cleanupnumber "$FINISHEDNUMBER")"
 		mmcli -m any --voice-delete-call "$FINISHEDCALLID"
 
-		rm -f "$XDG_RUNTIME_DIR/${FINISHEDCALLID}.monitoredcall"
+		rm -f "$XDG_RUNTIME_DIR/sxmo_calls/${FINISHEDCALLID}.monitoredcall"
 
 		CONTACT="$(sxmo_contacts.sh --name "$FINISHEDNUMBER")"
 		[ "$CONTACT" = "???" ] && CONTACT="$FINISHEDNUMBER"
 
 		TIME="$(date +%FT%H:%M:%S%z)"
 		mkdir -p "$SXMO_LOGDIR"
-		if [ -f "$XDG_RUNTIME_DIR/${FINISHEDCALLID}.discardedcall" ]; then
+		if [ -f "$XDG_RUNTIME_DIR/sxmo_calls/${FINISHEDCALLID}.discardedcall" ]; then
 			#this call was discarded
 			sxmo_notify_user.sh "Call with $CONTACT terminated"
 			stderr "Discarded call from $FINISHEDNUMBER"
 			printf %b "$TIME\tcall_finished\t$FINISHEDNUMBER\n" >> "$SXMO_LOGDIR/modemlog.tsv"
-		elif [ -f "$XDG_RUNTIME_DIR/${FINISHEDCALLID}.pickedupcall" ]; then
+		elif [ -f "$XDG_RUNTIME_DIR/sxmo_calls/${FINISHEDCALLID}.pickedupcall" ]; then
 			#this call was picked up
 			sxmo_notify_user.sh "Call with $CONTACT terminated"
 			sxmo_hook_statusbar.sh volume
 			stderr "Finished call from $FINISHEDNUMBER"
 			printf %b "$TIME\tcall_finished\t$FINISHEDNUMBER\n" >> "$SXMO_LOGDIR/modemlog.tsv"
-		elif [ -f "$XDG_RUNTIME_DIR/${FINISHEDCALLID}.hangedupcall" ]; then
+		elif [ -f "$XDG_RUNTIME_DIR/sxmo_calls/${FINISHEDCALLID}.hangedupcall" ]; then
 			#this call was hung up by the user
 			sxmo_notify_user.sh "Call with $CONTACT terminated"
 			stderr "Finished call from $FINISHEDNUMBER"
 			printf %b "$TIME\tcall_finished\t$FINISHEDNUMBER\n" >> "$SXMO_LOGDIR/modemlog.tsv"
-		elif [ -f "$XDG_RUNTIME_DIR/${FINISHEDCALLID}.initiatedcall" ]; then
+		elif [ -f "$XDG_RUNTIME_DIR/sxmo_calls/${FINISHEDCALLID}.initiatedcall" ]; then
 			#this call was hung up by the contact
 			sxmo_notify_user.sh "Call with $CONTACT terminated"
 			sxmo_hook_statusbar.sh volume
 			stderr "Finished call from $FINISHEDNUMBER"
 			printf %b "$TIME\tcall_finished\t$FINISHEDNUMBER\n" >> "$SXMO_LOGDIR/modemlog.tsv"
-		elif [ -f "$XDG_RUNTIME_DIR/${FINISHEDCALLID}.mutedring" ]; then
+		elif [ -f "$XDG_RUNTIME_DIR/sxmo_calls/${FINISHEDCALLID}.mutedring" ]; then
 			#this ring was muted up
 			stderr "Muted ring from $FINISHEDNUMBER"
 			printf %b "$TIME\tring_muted\t$FINISHEDNUMBER\n" >> "$SXMO_LOGDIR/modemlog.tsv"
@@ -76,7 +79,9 @@ checkforfinishedcalls() {
 			#this is a missed call
 			# Add a notification for every missed call
 			sxmo_hook_statusbar.sh volume
-			stderr "Missed call from $FINISHEDNUMBER"
+
+			NOTIFMSG="Missed call from $CONTACT ($FINISHEDNUMBER)"
+			stderr "$NOTIFMSG"
 			printf %b "$TIME\tcall_missed\t$FINISHEDNUMBER\n" >> "$SXMO_LOGDIR/modemlog.tsv"
 
 			stderr "Invoking missed call hook (async)"
@@ -84,9 +89,9 @@ checkforfinishedcalls() {
 
 			sxmo_notificationwrite.sh \
 				random \
-				"sxmo_terminal.sh -e sh -c \"echo 'Missed call from $CONTACT at $(date)' && read\"" \
+				"TERMNAME='$NOTIFMSG' sxmo_terminal.sh sh -c \"echo '$NOTIFMSG at $(date)' && read\"" \
 				none \
-				"Missed $icon_phn $CONTACT"
+				"Missed $icon_phn $CONTACT ($FINISHEDNUMBER)"
 		fi
 
 		# If it was the last call
@@ -95,10 +100,10 @@ checkforfinishedcalls() {
 			sxmo_vibrate 1000 &
 			sxmo_daemons.sh stop incall_menu
 			sxmo_daemons.sh stop calling_proximity_lock
+
 			if ! sxmo_modemaudio.sh reset_audio; then
 				sxmo_notify_user.sh --urgency=critical "We failed to reset call audio"
 			fi
-			setsid -f sh -c 'sleep 2; sxmo_hook_statusbar.sh call_duration'
 		else
 			# Or refresh the menu
 			sxmo_daemons.sh start incall_menu sxmo_modemcall.sh incall_menu
@@ -114,9 +119,9 @@ checkforincomingcalls() {
 	)"
 	[ -z "$VOICECALLID" ] && return
 
-	[ -f "$XDG_RUNTIME_DIR/${VOICECALLID}.monitoredcall" ] && return # prevent multiple rings
-	find "$XDG_RUNTIME_DIR" -name "$VOICECALLID.*" -delete 2>/dev/null # we cleanup all dangling event files
-	touch "$XDG_RUNTIME_DIR/${VOICECALLID}.monitoredcall" #this signals that we handled the call
+	[ -f "$XDG_RUNTIME_DIR/sxmo_calls/${VOICECALLID}.monitoredcall" ] && return # prevent multiple rings
+	rm "$XDG_RUNTIME_DIR/sxmo_calls/$VOICECALLID."* 2>/dev/null # we cleanup all dangling event files
+	touch "$XDG_RUNTIME_DIR/sxmo_calls/${VOICECALLID}.monitoredcall" #this signals that we handled the call
 
 	# Determine the incoming phone number
 	stderr "Incoming Call..."
@@ -238,4 +243,6 @@ checkfornewtexts() {
 	done
 }
 
+sxmo_mutex.sh can_suspend lock "Modem is used"
 "$@"
+sxmo_mutex.sh can_suspend free "Modem is used"
