@@ -66,6 +66,16 @@ pickup() {
 			;;
 		*)
 			sxmo_notify_user.sh --urgency=critical "Couldn't initialize call with callid <$CALLID>; unknown direction <$DIRECTION>"
+			# if we try to make an outgoing call while
+			# already on an outgoing call, it crashes the modem and
+			# gets us here.  We need to rm -rf
+			# $XDG_RUNTIME_DIR/sxmo_call/* before we can call
+			# again.
+			#
+			rm "$XDG_RUNTIME_DIR/sxmo_calls/"* 2>/dev/null || true
+			rm -f "$XDG_RUNTIME_DIR"/sxmo.ring.pid 2>/dev/null
+			rm -f "$SXMO_NOTIFDIR"/incomingcall* 2>/dev/null
+			return 1
 			;;
 	esac
 }
@@ -113,17 +123,24 @@ list_active_calls() {
 }
 
 incall_menu() {
+	# Note that mute mic does NOT actually work:
+	# See: https://gitlab.com/mobian1/callaudiod/-/merge_requests/10
+
 	# We have an active call
 	while list_active_calls | grep -q . ; do
 		CHOICES="$(grep . <<EOF
 $icon_cls Close menu                ^ exit
-$icon_aru Volume up                 ^ sxmo_audio.sh vol up 20
-$icon_ard Volume down               ^ sxmo_audio.sh vol down 20
-$icon_rol Reset call audio          ^ sxmo_modemaudio.sh setup_audio
-$icon_spk Speaker $(sxmo_modemaudio.sh is_enabled_speaker \
+$icon_aru Volume ($(sxmo_audio.sh vol get)) ^ sxmo_audio.sh vol up 20
+$icon_ard Volume  ^ sxmo_audio.sh vol down 20
+$(sxmo_modemaudio.sh is_enabled_speaker \
 	&& printf "%s" "$icon_ton" \
 	|| printf "%s" "$icon_tof"
-) ^ sxmo_modemaudio.sh toggle_speaker
+) Speaker ^ sxmo_modemaudio.sh toggle_speaker
+$(sxmo_modemaudio.sh is_muted_mic \
+	&& printf "%s Mic ^ sxmo_modemaudio.sh unmute_mic" "$icon_tof" \
+	|| printf "%s Mic ^ sxmo_modemaudio.sh mute_mic" "$icon_ton"
+)
+$icon_cfg Audio Settings ^ sxmo_audio.sh
 $(
 	list_active_calls | while read -r line; do
 		CALLID="$(printf %s "$line" | cut -d" " -f1 | xargs basename)"
@@ -134,14 +151,14 @@ $(
 			*"(ringing-in)")
 				# TODO switch to this call
 				printf "%s Hangup %s ^ hangup %s\n" "$icon_phx" "$CONTACT" "$CALLID"
-				printf "%s Mute %s ^ mute %s\n" "$icon_phx" "$CONTACT" "$CALLID"
+				printf "%s Ignore %s ^ mute %s\n" "$icon_phx" "$CONTACT" "$CALLID"
 				;;
 			*"(held)")
 				# TODO switch to this call
 				printf "%s Hangup %s ^ hangup %s\n" "$icon_phx" "$CONTACT" "$CALLID"
 				;;
 			*)
-				printf "%s DTMF Tones %s ^ dtmf_menu %s\n" "$icon_mus" "$CONTACT" "$CALLID"
+				printf "%s DTMF Tones %s ^ sxmo_terminal.sh sxmo_dtmf.sh %s\n" "$icon_mus" "$CONTACT" "$CALLID"
 				printf "%s Hangup %s ^ hangup %s\n" "$icon_phx" "$CONTACT" "$CALLID"
 				;;
 		esac
@@ -150,12 +167,6 @@ $(
 EOF
 	)"
 
-		# Disabled cause no effect on pinephone
-		# https://gitlab.com/mobian1/callaudiod/-/merge_requests/10
-		# $icon_mic Mic $(sxmo_modemaudio.sh is_muted_mic \
-		# 	&& printf "%s ^ sxmo_modemaudio.sh unmute_mic " "$icon_tof" \
-		# 	|| printf "%s ^ sxmo_modemaudio.sh mute_mic" "$icon_ton"
-		# )
 
 		PICKED="$(
 			printf "%s\n" "$CHOICES" |
@@ -173,29 +184,13 @@ EOF
 	wait
 }
 
-dtmf_menu() {
-	CALLID="$1"
-
-	sxmo_keyboard.sh close
-	KEYBOARD_ARGS="-o -l dialer" sxmo_keyboard.sh open | \
-		sxmo_splitchar | xargs -n1 printf "%s\n" | stdbuf -o0 grep '[0-9A-D*#]' | \
-		xargs -r -I{} -n1 mmcli -m any -o "$CALLID" --send-dtmf="{}" &
-
-	# Closed return to default menu
-	if ! printf "Close Menu\n" | sxmo_dmenu.sh -i -p "DTMF Tone"; then
-		sxmo_keyboard.sh close
-	fi
-
-	sxmo_keyboard.sh close
-}
-
 mute() {
 	CALLID="$1"
 
 	# this signals that we muted this ring
 	touch "$XDG_RUNTIME_DIR/sxmo_calls/${CALLID}.mutedring"
 	sxmo_log "Invoking mute_ring hook (async)"
-	sxmo_hook_mute_ring.sh "$CONTACTNAME" &
+	sxmo_hook_mute_ring.sh &
 	log_event "ring_mute" "$1"
 }
 
@@ -215,18 +210,12 @@ incoming_call_menu() {
 			cat <<EOF | sxmo_dmenu.sh -i -H "$pickup_height" -p "$CONTACTNAME"
 $icon_phn Pickup
 $icon_phx Hangup
-$icon_mut Mute
+$icon_mut Ignore
 EOF
 		)" || exit
 
 		case "$PICKED" in
 			"$icon_phn Pickup")
-				if [ -e "$XDG_CONFIG_HOME/sxmo/.ringmode" ] && \
-					! [ -e "$XDG_CONFIG_HOME/sxmo/.ringmode.beforecall" ]; then
-					mv "$XDG_CONFIG_HOME/sxmo/.ringmode" "$XDG_CONFIG_HOME/sxmo/.ringmode.beforecall"
-				fi
-				echo Vibrate > "$XDG_CONFIG_HOME/sxmo/.ringmode"
-
 				if ! sxmo_modemaudio.sh setup_audio; then
 					sxmo_notify_user.sh --urgency=critical "We failed to setup call audio"
 					return 1
@@ -243,7 +232,7 @@ EOF
 			"$icon_phx Hangup")
 				hangup "$1"
 				;;
-			"$icon_mut Mute")
+			"$icon_mut Ignore")
 				mute "$1"
 				;;
 		esac
