@@ -9,9 +9,16 @@
 set -e
 
 dial_number() {
+
+	# on pinepone if you attempt to make a call while in a call, modem crashes
+	if sxmo_modemcall.sh list_active_calls | grep -q .; then
+		sxmo_notify_user.sh "Cannot make call while in a call (for now)."
+		return 0
+	fi
+
 	NUMBER="$1"
 
-	CLEANEDNUMBER="$(pn find ${DEFAULT_COUNTRY:+-c "$DEFAULT_COUNTRY"} "$1")"
+	CLEANEDNUMBER="$(pnc find ${DEFAULT_COUNTRY:+-c "$DEFAULT_COUNTRY"} "$1")"
 	if [ -n "$CLEANEDNUMBER" ] && [ "$NUMBER" != "$CLEANEDNUMBER" ]; then
 		NUMBER="$(cat <<EOF | sxmo_dmenu.sh -p "Rewrite ?"
 $NUMBER
