@@ -142,16 +142,17 @@ addnetworkwpamenu() {
 		echo "$icon_cls Close Menu" |
 			sxmo_dmenu_with_kb.sh -p "Passphrase"
 	)"
-	[ -z "$PASSPHRASE" ] && return
+	if [ -z "$PASSPHRASE" ]; then
+		unset PASSPHRASE
+	fi
 	echo "$PASSPHRASE" | grep -q "Close Menu" && return
 
 	RES="$(nofail nmcli c add \
 		type wifi \
 		ifname wlan0 \
 		con-name "$SSID" \
-		802-11-wireless-security.key-mgmt wpa-psk \
 		ssid "$SSID" \
-		802-11-wireless-security.psk "$PASSPHRASE" 2>&1)"
+		${PASSPHRASE:+802-11-wireless-security.key-mgmt wpa-psk 802-11-wireless-security.psk "$PASSPHRASE"} 2>&1)"
 	stderr "$RES"
 	notify-send "$RES"
 }
@@ -236,12 +237,25 @@ networksmenu() {
 			rfkill list wifi | grep -q "yes" || WIFI_ENABLED=1
 
 			grep . << EOF | sxmo_dmenu.sh -p "Networks"
-$(connections)
+$(
+	if [ -z "$WIFI_ENABLED" ]; then
+		connections | grep -v "$icon_wif"
+	else
+		connections
+	fi
+)
 $icon_mod Add a GSM Network
 $([ -z "$WIFI_ENABLED" ] || printf "%s Add a WPA Network\n" "$icon_wif")
 $([ -z "$WIFI_ENABLED" ] || printf "%s Add a Wifi Hotspot\n" "$icon_wif")
 $icon_usb Add a USB Hotspot
 $icon_cls Delete a Network
+$(
+	if [ -z "$WIFI_ENABLED" ]; then
+		printf "%s Enable Wifi\n" "$icon_wif"
+	else
+		printf "%s Disable Wifi\n" "$icon_wif"
+	fi
+)
 $icon_cfg Nmtui
 $icon_cfg Ifconfig
 $([ -z "$WIFI_ENABLED" ] || printf "%s Scan Wifi Networks\n" "$icon_wif")
@@ -281,6 +295,9 @@ EOF
 			*"Scan Wifi Networks" )
 				sxmo_terminal.sh watch -n 2 nmcli d wifi list || continue # Killeable
 				;;
+			*"Disable Wifi"|*"Enable Wifi" )
+				doas sxmo_wifitoggle.sh
+				;;
 			*)
 				toggleconnection "$CHOICE"
 				;;
