@@ -9,6 +9,9 @@
 
 set -e
 
+# on arch we manage mmsd with systemd instead of superd
+alias superctl='systemctl --user'
+
 VVM_BASE_DIR="${SXMO_VVM_BASE_DIR:-"$HOME"/.vvm/modemmanager}"
 VVMCONFIG="$VVM_BASE_DIR/vvm"
 
@@ -65,10 +68,10 @@ newfile() {
 
 mkdir -p "$VVM_BASE_DIR"
 
-systemctl --user stop vvmd
+superctl stop vvmd
 
 finish() {
-	systemctl --user start vvmd
+	superctl start vvmd
 }
 trap 'finish' EXIT
 
