@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 0fa59a4972de3206fa31a04b2eb23ab0
+# configversion: 564170c7a18d9b5f0ce9bf8bbb74cbb6
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -12,7 +12,7 @@
 sxmo_log "transitioning to stage unlock"
 printf unlock > "$SXMO_STATE"
 
-sxmo_hook_statusbar.sh state_change
+sxmo_daemons.sh start state_change_bar sxmo_hook_statusbar.sh state_change
 
 sxmo_wm.sh dpms off
 sxmo_wm.sh inputevent touchscreen on
