@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 27538f7293527f58c6f44839c69aeb85
+# configversion: 0f596a22eb8ff28f226bf37338e9b741
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 # shellcheck disable=SC2154
@@ -21,6 +21,7 @@ write_line_app() {
 	fi
 }
 
+write_line_app jami-qt "$icon_msg Jami" "jami-qt"
 write_line_app aerc "$icon_eml Aerc" "sxmo_terminal.sh aerc"
 write_line_app amfora "$icon_glb Amfora" "sxmo_terminal.sh amfora"
 write_line_app alpine "$icon_eml Alpine" "sxmo_terminal.sh alpine"
@@ -37,6 +38,7 @@ write_line_app emacs "$icon_edt Emacs (X)" "emacs"
 write_line_app epiphany "$icon_glb Epiphany" "epiphany"
 write_line_app epy "$icon_bok Epy" "sxmo_terminal.sh epy"
 write_line_app evince "$icon_bok Evince" "evince"
+write_line_app falkon "$icon_flk Falkon" "falkon"
 write_line_app firefox "$icon_ffx Firefox" "firefox"
 write_line_app firefox-esr "$icon_ffx Firefox ESR" "firefox-esr"
 write_line_app foliate "$icon_bok Foliate" "foliate"
