@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: e2bb8efca5e835fd6021753c63d11605
+# configversion: 9849a76420ec0adeeeb5039e3411b708
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -45,8 +45,9 @@ case "$WMCLASS" in
 		CHOICES="
 			$icon_plk Modem PIN                ^ 0 ^ sxmo_unlocksim.sh
 			$icon_phn Modem Monitor $(
-				sxmo_daemons.sh running modem_monitor -q &&
-				printf %b "$icon_ton ^ 1 ^ sxmo_daemons.sh stop modem_monitor" || printf %b "$icon_tof ^ 1 ^ sxmo_daemons.sh start modem_monitor sxmo_modemmonitor.sh"
+				superd_service_isrunning sxmo_modemmonitor &&
+				printf %b "$icon_ton ^ 1 ^ superctl stop sxmo_modemmonitor" ||
+				printf %b "$icon_tof ^ 1 ^ superctl start sxmo_modemmonitor"
 			) && sxmo_hook_statusbar.sh modem_monitor
 			$icon_wrh Restart System Daemons     ^ 1 ^ sxmo_hook_restart_modem_daemons.sh && sxmo_hook_statusbar.sh modem
 			$icon_inf Modem Info                 ^ 0 ^ sxmo_modeminfo.sh
@@ -172,6 +173,19 @@ case "$WMCLASS" in
 		"
 		WINNAME=Sxiv
 		;;
+	*imv*)
+		# imv
+		CHOICES="
+			$icon_arr Next          ^ 1 ^ sxmo_type -k Right
+			$icon_arl Previous      ^ 1 ^ sxmo_type -k Left
+			$icon_zmi Zoom in       ^ 1 ^ sxmo_type -k i
+			$icon_zmo Zoom out      ^ 1 ^ sxmo_type -k minus
+			$icon_exp Zoom to fit   ^ 1 ^ sxmo_type -k r
+			$icon_ror Rotate        ^ 1 ^ sxmo_type -M ctrl r
+			$icon_inf Toggle filename ^ 1 ^ sxmo_type -k d
+		"
+		WINNAME=Imv
+		;;
 	*kasts*)
 		CHOICES="
 			$icon_mus Audio ^ 0 ^ sxmo_audio.sh
@@ -359,9 +373,8 @@ case "$WMCLASS" in
 				$icon_mnu Terminal menu ^ 0 ^ sxmo_appmenu.sh $WMCLASS
 			"
 			WINNAME=weechat
-		elif printf %s "$WMNAME" | grep -qi -w "sms"; then
-			# TODO: Ensure $number is valid.
-			number="$(printf %s "$WMNAME" | sed -e 's|^\"||' -e 's|\"$||' | cut -f1 -d' ')"
+		elif printf %s "$WMNAME" | grep -qi -w "sms\|missed call"; then
+			number="$(printf "%s\n" "$WMNAME" | xargs -0 pnc find | tr -d '\n')"
 			#sms
 			CHOICES="
 				$icon_msg Conversation   ^ 0 ^ sxmo_terminal.sh sxmo_modemtext.sh conversationloop $number
@@ -370,7 +383,7 @@ case "$WMCLASS" in
 				$([ -d "$SXMO_LOGDIR/$number/attachments" ] && echo "$icon_att View Attachments ^ 1 ^ sxmo_files.sh $SXMO_LOGDIR/$number/attachments --date-sort")
 				$(
 
-				found_numbers="$(printf %s "$number" | xargs -I{} pn find "{}")"
+				found_numbers="$(printf %s "$number" | xargs -I{} pnc find "{}")"
 				printf "%s\n" "$found_numbers" | while read -r line; do
 					sxmo_contacts.sh --name "$line" | grep -q '???' && echo "$icon_usr Add $line ^ 1 ^ sxmo_contactmenu.sh newcontact $line"
 				done
@@ -384,7 +397,7 @@ case "$WMCLASS" in
 				$icon_ard Scroll down     ^ 1 ^ sxmo_type -M Shift -M Ctrl f
 				$icon_mnu Terminal menu ^ 0 ^ sxmo_appmenu.sh $WMCLASS
 			"
-			WINNAME=sms
+			WINNAME=phone
 		elif printf %s "$WMNAME" | grep -qi -w "cmus"; then
 			# cmus
 			# requires `:set set_term_title=false` in cmus to match the application
@@ -525,6 +538,23 @@ case "$WMCLASS" in
 		"
 		WINNAME=Surf
 		;;
+	*falkon*)
+		# Falkon
+		CHOICES="
+			$icon_flt Pipe URL          ^ 0 ^ sxmo_urlhandler.sh
+			$icon_tab New Tab           ^ 0 ^ sxmo_type -M Ctrl t
+			$icon_win New Window        ^ 0 ^ sxmo_type -M Ctrl n
+			$icon_cls Close Tab         ^ 0 ^ sxmo_type -M Ctrl w
+			$icon_zmi Zoom            ^ 1 ^ sxmo_type -M Ctrl -k plus
+			$icon_zmo Zoom            ^ 1 ^ sxmo_type -M Ctrl -k minus
+			$icon_arl History        ^ 1 ^ sxmo_type -M Alt -k Left
+			$icon_arr History        ^ 1 ^ sxmo_type -M Alt -k Right
+			$icon_win Home           ^ 0 ^ sxmo_type -M Alt -k Home
+			$icon_zmo Full Screen    ^ 0 ^ sxmo_type -k F11
+			$icon_rld Refresh     ^ 0 ^ sxmo_type -M Shift -M Ctrl r
+		"
+		WINNAME=Falkon
+		;;
 	*firefox*)
 		# Firefox
 		CHOICES="
