@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: b5fe8b5788a858c177d8fbebf45a284c
+# configversion: 59dd2277d8058205c2ae20f05b59e322
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -13,6 +13,8 @@
 newstate="$2"
 # reason="$3" # 0 or 1
 
+sxmo_debug "$2 (old: $1 [reason: $3])"
+
 case "$newstate" in
 	"locked")
 		sxmo_log "State is locked.  Attempting to unlock."
@@ -20,6 +22,12 @@ case "$newstate" in
 			sxmo_unlocksim.sh
 		fi
 		;;
+	"enabling")
+		sxmo_log "State is enabling. Clearing stale call files."
+		rm "$XDG_RUNTIME_DIR"/sxmo_calls/* 2>/dev/null
+		rm -f "$XDG_RUNTIME_DIR"/sxmo.ring.pid 2>/dev/null
+		rm -f "$SXMO_NOTIFDIR"/incomingcall* 2>/dev/null
+		;;
 	"registered")
 		sxmo_log "State is registered.  Checking for calls and messages."
 
