@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 04f2fc0891ccdadc2cd73216c648c8fb
+# configversion: 72930bc53d64a3cce0338cf500d019a0
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -21,7 +21,7 @@
 if ! sxmo_modemcall.sh list_active_calls | grep -q active; then
 
 	if [ ! -f "$XDG_CONFIG_HOME"/sxmo/.noring ]; then
-		mpv --no-resume-playback --quiet --no-video "$SXMO_TEXTSOUND" >/dev/null &
+		mpv --no-resume-playback --quiet --no-video "$SXMO_TEXTSOUND" >> /dev/null 2>&1
 	fi
 
 	if [ ! -f "$XDG_CONFIG_HOME"/sxmo/.novibrate ]; then
