@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 49e66c72839317096d7bb9d66cb51475
+# configversion: a9add8fc72a39fd3f44e16245c319d3b
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -15,6 +15,7 @@
 #colours using pango markup
 if [ "$SXMO_WM" = "sway" ]; then
 	SPAN_RED="<span foreground=\"#ff5454\">"
+	SPAN_REDBG="<span foreground=\"#ffffff\" background=\"#ff5454\">"
 	SPAN_GREEN="<span foreground=\"#54ff54\">"
 	SPAN_ORANGE="<span foreground=\"#ffa954\">"
 	BOLD="<b>"
@@ -22,6 +23,7 @@ if [ "$SXMO_WM" = "sway" ]; then
 	ENDSPAN="</span>"
 else
 	SPAN_RED=""
+	SPAN_REDBG=""
 	SPAN_GREEN=""
 	SPAN_ORANGE=""
 	BOLD=""
@@ -38,26 +40,10 @@ set_state() {
 		sxmo_status.sh del 0-state
 	else
 		STATE_LABEL=$(tr '[:lower:]' '[:upper:]' < "$SXMO_STATE")
-		echo "${SPAN_RED}${BOLD}${STATE_LABEL}${ENDBOLD}${ENDSPAN}" | sxmo_status.sh add 0-state
+		printf "%b%b%s%b%b" "${SPAN_REDBG}" "${BOLD}" "${STATE_LABEL}" "${ENDBOLD}" "${ENDSPAN}" | sxmo_status.sh add 0-state
 	fi
 }
 
-set_call_duration() {
-	if ! pgrep sxmo_modemcall.sh > /dev/null; then
-		sxmo_status.sh del 0-call-duration
-		return
-	fi
-
-	NOWS="$(date +"%s")"
-	CALLSTARTS="$(date +"%s" -d "$(
-		grep -aE 'call_start|call_pickup' "$XDG_DATA_HOME"/sxmo/modem/modemlog.tsv |
-		tail -n1 |
-		cut -f1
-	)")"
-	CALLSECONDS="$(printf "%s - %s" "$NOWS" "$CALLSTARTS" | bc)"
-	printf "%ss " "$CALLSECONDS" | sxmo_status.sh add 5-call-duration
-}
-
 _modem() {
 	MMCLI="$(mmcli -m any -J 2>/dev/null)"
 	MODEMSTATUS=""
@@ -77,10 +63,10 @@ _modem() {
 				printf "%s%s%s" "$SPAN_RED" "$icon_mdd" "$ENDSPAN"
 				;;
 			disabling)
-				printf ">%s" "$icon_mdd"
+				printf "%s%s%s" "$SPAN_ORANGE" "$icon_ena" "$ENDSPAN"
 				;;
 			enabling) # modem enabled but neither registered (cell) nor connected (data)
-				printf ">%s" "$icon_ena"
+				printf "%s%s%s" "$SPAN_GREEN" "$icon_ena" "$ENDSPAN"
 				;;
 			enabled)
 				printf "%s" "$icon_ena"
@@ -112,8 +98,11 @@ _modem() {
 	fi
 
 	case "$MODEMSTATUS" in
-		"connected")
+		connected|registered|connecting|disconnecting)
 			printf " "
+			[ "$MODEMSTATUS" = "registered" ] && printf %s "$SPAN_RED"
+			[ "$MODEMSTATUS" = "connecting" ] && printf %s "$SPAN_GREEN"
+			[ "$MODEMSTATUS" = "disconnecting" ] && printf %s "$SPAN_ORANGE"
 			USEDTECHS="$(printf %s "$MMCLI" | jq -r '.modem.generic."access-technologies"[]')"
 			case "$USEDTECHS" in
 				*5gnr*)
@@ -133,15 +122,12 @@ _modem() {
 					;;
 				*)
 					sxmo_log "WARNING: USEDTECHS: $USEDTECHS"
-					printf "<%s>" "$USEDTECHS"
+					printf "(%s)" "$USEDTECHS"
 					;;
 			esac
-			;;
-		"connecting")
-			printf " >>"
-			;;
-		"disconnecting")
-			printf " <<"
+			[ "$MODEMSTATUS" = "registered" ] && printf %s "$ENDSPAN"
+			[ "$MODEMSTATUS" = "connecting" ] && printf %s "$ENDSPAN"
+			[ "$MODEMSTATUS" = "disconnecting" ] && printf %s "$ENDSPAN"
 			;;
 	esac
 }
@@ -150,18 +136,22 @@ set_modem() {
 	_modem | sxmo_status.sh add 10-modem-status
 }
 
-set_modem_monitor() {
-	if sxmo_daemons.sh running modem_monitor -q; then
-		sxmo_status.sh add 20-modem-monitor-status "$icon_mod"
-	else
-		sxmo_status.sh del 20-modem-monitor-status
-	fi
-}
-
 set_wifi() {
 	case "$(cat "/sys/class/net/$2/operstate")" in
-		"up") sxmo_status.sh add "30-network-$2-status" "$icon_wif" ;;
-		*) sxmo_status.sh del "30-network-$2-status" ;;
+		"up")
+			# detect hotspot
+			if nmcli -g UUID c show --active | while read -r uuid; do
+				nmcli -g 802-11-wireless.mode c show "$uuid"
+			done | grep -q '^ap$'; then
+				sxmo_status.sh add "30-network-$2-status" "$icon_wfh"
+			else
+				sxmo_status.sh add "30-network-$2-status" "$icon_wif"
+			fi
+			;;
+		*)
+			sxmo_status.sh add "30-network-$2-status" "$SPAN_RED$icon_wif$ENDSPAN"
+			rfkill list wifi | grep -q "yes" && sxmo_status.sh add "30-network-$2-status" "$icon_wfo"
+			;;
 	esac
 }
 
@@ -263,16 +253,76 @@ _battery() {
 	done
 }
 
+set_lockedby() {
+	sxmo_mutex.sh can_suspend list | sort -u | while read -r line; do
+		case "$line" in
+			"SSH"*|"Mosh"*)
+				printf "S\n"
+				;;
+			"Hotspot"*)
+				printf "H\n"
+				;;
+			"Camera postprocessing")
+				printf "C\n"
+				;;
+			"Proximity lock is running")
+				printf "P\n"
+				;;
+			"Ongoing call")
+				printf "O\n"
+				;;
+			"Modem is used")
+				printf "M\n"
+				;;
+			"Executing cronjob")
+				printf "X\n"
+				;;
+			"Waiting for cronjob")
+				printf "W\n"
+				;;
+			"Manually disabled")
+				printf "N\n" #N = No suspend
+				;;
+			"Playing with leds"|"Checking some mutexes")
+				printf "*\n"
+				;;
+			*"is playing"*)
+				printf "%s\n" "$icon_mus"
+				;;
+			*)
+				printf "%s\n" "$line" | sed 's/\(.\{7\}\).*/\1…/g'
+				;;
+		esac
+	done | sort -u | tr -d '\n' | sxmo_status.sh add 41-lockedby-status
+}
+
 set_battery() {
 	 _battery | sxmo_status.sh add 40-battery-status
 }
 
+set_notifications() {
+	[ -z "$SXMO_DISABLE_LEDS" ] && return
+	NNOTIFICATIONS="$(find "$SXMO_NOTIFDIR" -type f | wc -l)"
+	[ "$NNOTIFICATIONS" = 0 ] && sxmo_status.sh del notifs && return
+	printf "%s!: %d%s\n" "$SPAN_RED" "$NNOTIFICATIONS" "$ENDSPAN" | sxmo_status.sh add notifs
+}
+
 _volume() {
+	if sxmo_modemaudio.sh is_call_audio_mode; then
+		printf %s "$SPAN_GREEN"
+		sxmo_modemaudio.sh is_muted_mic && printf "%s " "$icon_mmc" || printf "%s " "$icon_mic"
+		sxmo_modemaudio.sh is_enabled_speaker && printf %s "$icon_spk" || printf %s "$icon_ear"
+		printf %s "$ENDSPAN"
+		return
+	fi
+
+	sxmo_audio.sh mic ismuted && printf "%s " "$icon_mmc" || printf "%s " "$icon_mic"
+
 	case "$(sxmo_audio.sh device get 2>/dev/null)" in
 		Speaker|"")
 			# nothing for default or pulse devices
 			;;
-		Headphones)
+		Headphones|Headphone)
 			printf "%s " "$icon_hdp"
 			;;
 		Earpiece)
@@ -281,13 +331,13 @@ _volume() {
 	esac
 
 	VOL="$(sxmo_audio.sh vol get)"
-	if [ -z "$VOL" ] || [ "$VOL" -eq 0 ]; then
+	if [ -z "$VOL" ] || [ "$VOL" = "muted" ]; then
 		printf "%s" "$icon_mut"
 	elif [ "$VOL" -gt 66 ]; then
 		printf "%s" "$icon_spk"
 	elif [ "$VOL" -gt 33 ]; then
 		printf "%s" "$icon_spm"
-	elif [ "$VOL" -gt 0 ]; then
+	elif [ "$VOL" -ge 0 ]; then
 		printf "%s" "$icon_spl"
 	fi
 }
@@ -301,7 +351,7 @@ case "$1" in
 		shift
 		set_network "$@"
 		;;
-	time|call_duration|modem|modem_monitor|battery|volume|state)
+	time|modem|battery|volume|state|lockedby|notifications)
 		set_"$1"
 		;;
 	periodics|state_change) # 55 s loop and screenlock triggers
@@ -313,12 +363,12 @@ case "$1" in
 	all)
 		sxmo_status.sh reset
 		set_time
-		set_call_duration
 		set_modem
-		set_modem_monitor
 		set_battery
 		set_volume
 		set_state
+		set_notifications
+		set_lockedby
 		;;
 	*)
 		exit # swallow it !
