@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 0dfdb9562c33c964d7301a2ae4263259
+# configversion: fa6591c65d672647180876bda677e84a
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -16,7 +16,7 @@ TERMNAME="$NUMBER SMS"
 export TERMNAME
 
 # If it's already open, switch to it.
-if [ "$SXMO_WM" = "sway" ]; then
+if [ "$SXMO_WM" = "sway" ] && [ -z "$SSH_CLIENT" ]; then
 	regesc_termname="$(echo "$TERMNAME" | sed 's|+|\\+|g')"
 	swaymsg "[title=\"^$regesc_termname\$\"]" focus && exit 0
 fi
