@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 373b48d3eab6f34c37305df73a5bb493
+# configversion: c7034e3e9ad35e76c3b3a5e0a461adf1
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -13,7 +13,7 @@ sxmo_daemons.sh stop periodic_blink
 
 pkill clickclack
 sxmo_keyboard.sh close
-pkill mpv #if any audio/video is playing, kill it (it might stutter otherwise)
+pkill -INT mpv #if any audio/video is playing, kill it (it might stutter otherwise)
 
 case "$SXMO_WM" in
 	dwm)
