@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: c1ff69ed3bf1d509159e2010db4fe1ba
+# configversion: 1717e9421576d738f711e3da97de1a9f
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -13,14 +13,14 @@ sxmo_log "transitioning to stage unlock"
 printf unlock > "$SXMO_STATE"
 
 sxmo_uniq_exec.sh sxmo_led.sh blink red green &
-LEDPID=$!
-sxmo_hook_statusbar.sh state_change
+sxmo_daemons.sh start state_change_bar sxmo_hook_statusbar.sh state_change
 
 sxmo_wm.sh dpms off
 sxmo_wm.sh inputevent touchscreen on
 superctl start sxmo_hook_lisgd
 
-wait "$LEDPID"
+# avoid dangling purple blinking when usb wakeup + power button…
+sxmo_daemons.sh stop periodic_blink
 
 NETWORKRTCSCAN="/sys/module/$SXMO_WIFI_MODULE/parameters/rtw_scan_interval_thr"
 if [ -w "$NETWORKRTCSCAN" ]; then
